@@ -12,12 +12,21 @@ from nctoolkit.api import (
 )
 
 from nctoolkit.unify import unify
+from nctoolkit.shape import open_shape
 
 from nctoolkit.validator import validator
 from nctoolkit.matchpoint import open_matchpoint
 
 
 from nctoolkit.cleanup import cleanup, clean_all, deep_clean, temp_check
+
+import atexit
+atexit.register(clean_all)
+import signal
+
+signal.signal(signal.SIGTERM, clean_all)
+signal.signal(signal.SIGINT, clean_all)
+
 from nctoolkit.create_ensemble import create_ensemble
 from nctoolkit.session import session_files
 from nctoolkit.show import nc_variables, nc_years, nc_months, nc_times
@@ -29,3 +38,13 @@ from nctoolkit.mp_adders import match_points
 session_info["cdo"] = cdo_version()
 
 validate_version()
+
+try:
+    from importlib.metadata import version as _version
+except ImportError:
+    from importlib_metadata import version as _version  
+
+try:
+    __version__ = _version("nctoolkit")
+except Exception:
+    __version__ = "999"
