@@ -1,4 +1,3 @@
-import atexit
 import glob
 import sys
 import copy
@@ -70,7 +69,7 @@ def time_limit(seconds):
 # A custom format for warnings.
 def custom_formatwarning(msg, *args, **kwargs):
     # ignore everything except the message
-    return str(msg) + "\n"
+    return "Warning: " + str(msg) + "\n"
 
 
 warnings.formatwarning = custom_formatwarning
@@ -88,6 +87,7 @@ session_info["precision"] = None
 session_info["parallel"] = False
 session_info["progress"] = "on"
 session_info["checks"] = True
+session_info["coast"] = False
 
 session_info["interactive"] = sys.__stdin__.isatty()
 
@@ -108,7 +108,7 @@ if platform.system() == "Linux":
 
 
 def update_options(kwargs):
-    valid_keys = ["thread_safe", "lazy", "cores", "precision", "temp_dir", "parallel", "checks", "progress"]
+    valid_keys = ["thread_safe", "lazy", "cores", "precision", "temp_dir", "parallel", "checks", "progress", "coast"]
 
     for key in kwargs:
         find = True
@@ -116,16 +116,16 @@ def update_options(kwargs):
             raise AttributeError(key + " is not a valid option")
 
         if key == "parallel" or key == "lazy" or key == "thread_safe":
-            if type(kwargs[key]) is not bool:
+            if not isinstance(kwargs[key], bool):
                 raise TypeError(f"{key} should be boolean")
 
         if key == "checks":
-            if type(kwargs[key]) is not bool:
+            if not isinstance(kwargs[key], bool):
                 raise TypeError(f"{key} should be boolean")
 
-        if type(kwargs[key]) is not bool and find:
+        if not isinstance(kwargs[key], bool) and find:
             if key == "temp_dir":
-                if type(kwargs[key]) is str:
+                if isinstance(kwargs[key], str):
                     if os.path.exists(kwargs[key]) is False:
                         raise ValueError("The temp_dir specified does not exist!")
                     session_info[key] = os.path.abspath(kwargs[key])
@@ -135,14 +135,14 @@ def update_options(kwargs):
                 if kwargs[key] not in ["on", "off", "auto", "of"]:
                     raise ValueError("progress must be one of 'on', 'off', 'auto'")
 
-                if kwargs[key] == "of": 
-                    session_info[key] = "off" 
+                if kwargs[key] == "of":
+                    session_info[key] = "off"
                 else:
                     session_info[key] = kwargs[key]
                 find = False
 
             if key == "cores" and find:
-                if type(kwargs[key]) is int:
+                if isinstance(kwargs[key], int):
                     if kwargs[key] > mp.cpu_count():
                         raise ValueError(
                             str(kwargs[key])
@@ -160,7 +160,7 @@ def update_options(kwargs):
                         if kwargs[key] not in ["I8", "I16", "I32", "F32", "F64", "default"]:
                             raise ValueError("precision supplied is not valid!")
                         if kwargs[key] == "default":
-                            session_info[key] = None 
+                            session_info[key] = None
                         else:
                             session_info[key] = kwargs[key]
                         find = False
@@ -249,16 +249,16 @@ def options(**kwargs):
             raise AttributeError(key + " is not a valid option")
 
         if key == "parallel" or key == "lazy" or key == "thread_safe":
-            if type(kwargs[key]) is not bool:
+            if isinstance(kwargs[key], bool):
                 raise TypeError(f"{key} should be boolean")
 
         if key == "checks":
-            if type(kwargs[key]) is not bool:
+            if isinstance(kwargs[key], bool):
                 raise TypeError(f"{key} should be boolean")
 
-        if type(kwargs[key]) is not bool:
+        if isinstance(kwargs[key], bool):
             if key == "temp_dir":
-                if type(kwargs[key]) is str:
+                if isinstance(kwargs[key], str):
                     if os.path.exists(kwargs[key]) is False:
                         raise ValueError("The temp_dir specified does not exist!")
                     session_info[key] = os.path.abspath(kwargs[key])
@@ -268,14 +268,14 @@ def options(**kwargs):
                 if kwargs[key] not in ["on", "off", "auto", "of"]:
                     raise ValueError("progress must be one of 'on', 'off', 'auto'")
 
-                if kwargs[key] == "of": 
-                    session_info[key] = "off" 
+                if kwargs[key] == "of":
+                    session_info[key] = "off"
                 else:
                     session_info[key] = kwargs[key]
                 return None
 
             if key == "cores":
-                if type(kwargs[key]) is int:
+                if isinstance(kwargs[key], int):
                     if kwargs[key] > mp.cpu_count():
                         raise ValueError(
                             str(kwargs[key])
@@ -388,9 +388,6 @@ if config_file is not None:
                 update_options({key:value})
 
 
-# register clean_all to clean temp files on exit
-atexit.register(clean_all)
-
 # run temp_check to see if any files are held over from previous sessions
 temp_check()
 
@@ -466,10 +463,10 @@ def open_geotiff(x = []):
     open_data : nctoolkit.DataSet
     """
 
-    if type(x) is str:
+    if isinstance(x, str):
         x = [x]
 
-    if type(x) is not list:
+    if not isinstance(x, list):
         raise ValueError("List of str was not supplied!")
 
     try:
@@ -552,7 +549,7 @@ def open_data(x=[], checks=True, **kwargs):
         if key == "source":
             source = kwargs[key]
 
-    if type(x) is str and thredds is False:
+    if isinstance(x, str) and thredds is False:
         if is_url(x) is False:
             x = glob.glob(x)
             if len(x) == 0:
@@ -564,13 +561,13 @@ def open_data(x=[], checks=True, **kwargs):
         raise ValueError("No data was supplied!")
 
     # coerce an iterable to a list
-    if type(x) is not str:
+    if not isinstance(x, str):
         x = [y for y in x]
         for ff in x:
-            if type(ff) is not str:
+            if not isinstance(ff, str):
                 raise TypeError("You have not supplied an iterable made of file paths!")
 
-    if type(x) is list:
+    if isinstance(x, list):
         if len(x) == 1:
             x = x[0]
 
@@ -581,7 +578,7 @@ def open_data(x=[], checks=True, **kwargs):
     if file_stop is not None:
         stop_time = min(file_stop, stop_time)
 
-    if type(x) is str:
+    if isinstance(x, str):
         if source != "file" or os.path.exists(x) is False:
 
             if is_url(x):
@@ -670,13 +667,13 @@ def open_data(x=[], checks=True, **kwargs):
     # Get rid of them..
     # Note: This will also ensure the original list is deep copied
 
-    if type(x) is list:
+    if isinstance(x, list):
         orig_size = len(x)
         x = list(dict.fromkeys(x))
         if len(x) < orig_size:
             warnings.warn(message="Duplicates in data set have been removed!")
 
-    if type(x) is list:
+    if isinstance(x, list):
         if source == "url":
 
             for ff in x:
@@ -730,7 +727,7 @@ def open_data(x=[], checks=True, **kwargs):
                         new_files.append(new_x)
                 x = new_files
 
-    if type(x) is list and source != "url":
+    if isinstance(x, list) and source != "url":
         if thredds is False:
 
             for ff in x:
@@ -747,7 +744,7 @@ def open_data(x=[], checks=True, **kwargs):
                         raise FileNotFoundError("Data set " + ff + " does not exist!")
 
     # if there is only one file in the list, change it to a single file
-    if type(x) is list:
+    if isinstance(x, list):
         if len(x) == 1:
             x = x[0]
 
@@ -755,8 +752,17 @@ def open_data(x=[], checks=True, **kwargs):
     d._thredds = thredds
 
     if (len(d) == 1) and checks and (thredds is False):
+        d_contents = d.contents.reset_index(drop = True)
+        try:
+            d_sub = d_contents.query("fill_value == 0.0").reset_index(drop = True)
+            if len(d_sub) > 0:
+                file_out = ",".join(list(d_sub.variable))
+                warnings.warn(f"These variables have 0 as the fill value: {file_out}. Set to a different fill value if you are using sensitive methods.")
+        except:
+            # warning will be trigger, so no need to do anything
+            blah = "blah"
 
-        list1 = d.contents.reset_index(drop=True).data_type
+        list1 = d_contents.data_type
         positions = [ind for ind, x in enumerate(list1) if x.startswith("I")]
         if len(positions):
             bad = list(d.contents.reset_index(drop=True).variable[positions])
@@ -804,11 +810,11 @@ def open_thredds(x=None, wait=None, checks=False):
 
     """
 
-    if type(checks) is not bool:
+    if not isinstance(checks, bool):
         raise TypeError("Please provide boolean for checks")
 
     if wait is not None:
-        if type(wait) is not int and float:
+        if not instance(wait, (int, float)):
             raise TypeError("Please provide an integer for wait!")
         if wait <= 0:
             raise ValueError("Please provide a positive value for wait!")
@@ -855,14 +861,14 @@ def open_url(x=None, ftp_details=None, wait=None, file_stop=None):
     """
 
     if wait is not None:
-        if type(wait) is not int:
+        if not isinstance(wait, int):
             raise TypeError("Please provide a valid wait!")
 
         if wait <= 0:
             raise TypeError("Please provide a valid wait!")
 
     if file_stop is not None:
-        if type(file_stop) is not int:
+        if not isinstance(file_stop, int):
             raise TypeError("Please provide a valid file_stop!")
 
         if file_stop <= 0:
@@ -899,7 +905,7 @@ def merge(*datasets, match=["day", "year", "month"]):
     """
     all_files = []
     for dataset in datasets:
-        if ("DataSet" in str(type(dataset))) is False:
+        if not isinstance(dataset, DataSet):
             raise TypeError("Please check everything is a DataSet object!")
         # make sure everything has been evaluated
         dataset.run()
@@ -924,10 +930,10 @@ def cor_time(x=None, y=None):
         Second dataset to use
     """
 
-    if ("DataSet" in str(type(x))) is False:
+    if not isinstance(x, DataSet):
         raise TypeError("Please check x is a dataset")
 
-    if ("DataSet" in str(type(y))) is False:
+    if not isinstance(y, DataSet):
         raise TypeError("Please check y is a dataset")
         # make sure everything has been evaluated
 
@@ -992,10 +998,10 @@ def cor_space(x=None, y=None):
         Second dataset to use
     """
 
-    if ("DataSet" in str(type(x))) is False:
+    if not isinstance(x, DataSet):
         raise TypeError("Please check x is a dataset")
 
-    if ("DataSet" in str(type(y))) is False:
+    if not isinstance(y, DataSet):
         raise TypeError("Please check y is a dataset")
         # make sure everything has been evaluated
 
@@ -1055,7 +1061,7 @@ class DataSet(object):
         # Attribuates of interest to users
         self.history = []
         self.start = start
-        if type(start) is str:
+        if isinstance(start, str):
             self._current = [start]
         else:
             self._current = start
@@ -1446,6 +1452,14 @@ class DataSet(object):
                         "data_type",
                     ],
                 ]
+                try:
+                    fills = []
+                    for vv in df.variable:
+                        fills.append(dataset.variables[vv]._FillValue)
+                    df["fill_value"] = fills
+                except:
+                    df = df
+
                 list_contents.append(df.assign(file=ff))
             except:
                 warnings.warn("Potential data format issues identified. Consider running check!")
@@ -1501,7 +1515,7 @@ class DataSet(object):
 
     @start.setter
     def start(self, value):
-        if type(value) is str:
+        if isinstance(value, str):
             self._start = [value]
         if isinstance(value, list):
             self._start = value
@@ -1518,7 +1532,7 @@ class DataSet(object):
         for ff in self:
             remove_safe(ff)
 
-        if type(value) is str:
+        if isinstance(value, str):
             append_safe(value)
             self._current = [value]
         if isinstance(value, list):
@@ -1557,16 +1571,28 @@ class DataSet(object):
         return new
 
     def __del__(self):
-        for ff in self:
-            remove_safe(ff)
-        for ff in self._safe:
-            remove_safe(ff)
-        if self._weights is not None:
-            remove_safe(self._weights)
-        if self._weights is not None:
-            remove_safe(self._grid)
+        if self is not None:
+            for ff in self:
+                if ff is not None:
+                    try:
+                        remove_safe(ff)
+                    except:
+                        blah = "blah"
+            for ff in self._safe:
+                if ff is not None:
+                    try:
+                        remove_safe(ff)
+                    except:
+                        blah = "blah"
+            if self._weights is not None:
+                remove_safe(self._weights)
+            if self._weights is not None:
+                remove_safe(self._grid)
 
-        cleanup()
+        try:
+            cleanup()
+        except:
+            blah = "blah"
 
     @start.deleter
     def start(self):
@@ -1723,9 +1749,11 @@ class DataSet(object):
     from nctoolkit.setters import set_year
     from nctoolkit.setters import set_day
     from nctoolkit.setters import as_missing
+    from nctoolkit.setters import set_fill
     from nctoolkit.setters import set_units
     from nctoolkit.setters import set_longnames
     from nctoolkit.setters import set_precision
+    from nctoolkit.setters import missing_as
 
     from nctoolkit.shift import shift
 
@@ -1784,4 +1812,4 @@ class DataSet(object):
     from nctoolkit.zonals import zonal_sum
 
     # Deprecated methods
-    from nctoolkit.deprecated import set_missing
+    #from nctoolkit.deprecated import set_missing
