@@ -103,7 +103,7 @@ def bloom_start(self, drop=False, **kwargs):
     """
     frame = inspect.currentframe()
 
-    if type(drop) is not bool:
+    if not isinstance(drop, bool):
         raise ValueError("drop is not boolean!")
 
     if len(kwargs) == 0:
@@ -280,7 +280,7 @@ def bloom_start(self, drop=False, **kwargs):
                         )
                         try:
                             new_x = eval(x_term, globals(), frame.f_back.f_locals)
-                            if type(new_x) is not str:
+                            if not isinstance(new_x, str):
                                 if is_number(str(new_x)):
                                     start = start.replace(
                                         x_term, str(new_x).replace(" ", "")
@@ -342,7 +342,7 @@ def bloom_start(self, drop=False, **kwargs):
                     try:
                         # need to tweak this so that it captures the output and returns an appropriate error
                         new_x = eval(x, globals(), frame.f_back.f_locals)
-                        if type(new_x) is str:
+                        if isinstance(new_x, str):
                             error_message = f"{x} evaluates to a string!"
                             raise ValueError(f"{x} evaluates to a string")
                         if is_number(str(new_x)) is False:
@@ -422,7 +422,7 @@ def bloom_start(self, drop=False, **kwargs):
                     new_term = eval(x, globals(), frame.f_back.f_locals)
                 except:
                     raise ValueError(f"{x} is not available!")
-                if "float" not in str(type(new_term)) and "int" not in str(
+                if not isinstance(new_term, (int, float)):
                     type(new_term)
                 ):
                     raise ValueError(f"{x} does not evaluate to numeric!")
@@ -445,7 +445,7 @@ def bloom_start(self, drop=False, **kwargs):
                     new_term = eval(x, globals(), frame.f_back.f_locals)
                 except:
                     raise ValueError(f"{x} is not available!")
-                if "float" not in str(type(new_term)) and "int" not in str(
+                if not isinstance(new_term, (int, float)):
                     type(new_term)
                 ):
                     raise ValueError(f"{x} does not evaluate to numeric!")
@@ -494,7 +494,7 @@ def bloom_start(self, drop=False, **kwargs):
                 if term in frame.f_back.f_locals:
                     try:
                         new_term = eval(term, globals(), frame.f_back.f_locals)
-                        if type(new_term) is str:
+                        if isinstance(new_term, str):
                             error_message = f"{term} does not evaluate to a numeric!"
                             raise ValueError(f"{term} does not evaluate to a numeric!")
 
@@ -578,7 +578,7 @@ def bloom_start(self, drop=False, **kwargs):
                 if term.split(".")[0] in frame.f_back.f_locals:
                     try:
                         new_term = eval(term, globals(), frame.f_back.f_locals)
-                        if type(new_term) is str:
+                        if isinstance(new_term, str):
                             raise ValueError(f"{new_term} is not numeric!")
                         if is_number(str(new_term)) is False:
                             raise ValueError(f"{new_term} is not numeric!")
