@@ -130,7 +130,7 @@ def compare(self, expression=None):
     if expression is None:
         raise ValueError("No expression supplied")
 
-    if type(expression) is not str:
+    if not isinstance(expression, str):
         raise TypeError("Expression supplied is not str")
 
     expression = fix_expr(expression)
@@ -140,10 +140,11 @@ def compare(self, expression=None):
 
 def __eq__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f"=={x}")
-        else:
+        except:
             self.eq(x)
     else:
         self.eq(x)
@@ -151,30 +152,33 @@ def __eq__(self, x):
 
 def __gt__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f">{x}")
-        else:
+        except:
             self.gt(x)
     else:
         self.gt(x)
 
 def __lt__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f"<{x}")
-        else:
+        except:
             self.lt(x)
     else:
         self.lt(x)
 
 def __le__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f"<={x}")
-        else:
+        except:
             self.le(x)
     else:
         self.le(x)
@@ -182,20 +186,22 @@ def __le__(self, x):
 
 def __ge__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f">={x}")
-        else:
+        except:
             self.ge(x)
     else:
         self.ge(x)
 
 def __ne__(self, x):
 
-    if type(x) is not str:
-        if str(x).isnumeric():
+    if not isinstance(x, str):
+        try:
+            test = float(x)
             self.compare(f"!={x}")
-        else:
+        except:
             self.ne(x)
     else:
         self.ne(x)
